@@ -1,6 +1,6 @@
 
 """
-Graph writer.  Input is graph edge.  Writes edges to Cassandra graph.
+Graph writer.  Input is graph edge.  Writes edges to Neo4j graph.
 """
 
 import pulsar
@@ -11,7 +11,7 @@ import time
 
 from neo4j import GraphDatabase
 
-from .... schema import Triple
+from .... schema import Triples
 from .... schema import triples_store_queue
 from .... log_level import LogLevel
 from .... base import Consumer
@@ -24,6 +24,7 @@ default_subscriber = module
 default_graph_host = 'bolt://neo4j:7687'
 default_username = 'neo4j'
 default_password = 'password'
+default_database = 'neo4j'
 
 class Processor(Consumer):
 
@@ -33,18 +34,19 @@ class Processor(Consumer):
         subscriber = params.get("subscriber", default_subscriber)
         graph_host = params.get("graph_host", default_graph_host)
         username = params.get("username", default_username)
-        password = params.get("passowrd", default_password)
+        password = params.get("password", default_password)
+        database = params.get("database", default_database)
 
         super(Processor, self).__init__(
             **params | {
                 "input_queue": input_queue,
                 "subscriber": subscriber,
-                "input_schema": Triple,
+                "input_schema": Triples,
                 "graph_host": graph_host,
             }
         )
 
-        self.db = "neo4j"
+        self.db = database
 
         self.io = GraphDatabase.driver(graph_host, auth=(username, password))
 
@@ -120,7 +122,7 @@ class Processor(Consumer):
 
             self.create_node(t.s.value)
 
-            if v.o.is_uri:
+            if t.o.is_uri:
                 self.create_node(t.o.value)
                 self.relate_node(t.s.value, t.p.value, t.o.value)
             else:
@@ -152,6 +154,12 @@ class Processor(Consumer):
             help=f'Neo4j password (default: {default_password})'
         )
 
+        parser.add_argument(
+            '--database',
+            default=default_database,
+            help=f'Neo4j database (default: {default_database})'
+        )
+
 def run():
 
     Processor.start(module, __doc__)
